# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class CalendarFieldIndex(metaclass=UnoConstMeta, type_name="com.sun.star.i18n.CalendarFieldIndex", name_space="com.sun.star.i18n"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.i18n.CalendarFieldIndex``"""
        pass

    class CalendarFieldIndexEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.i18n.CalendarFieldIndex", name_space="com.sun.star.i18n"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.i18n.CalendarFieldIndex`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.i18n import CalendarFieldIndex as CalendarFieldIndex
    else:
        # keep document generators happy
        from ...lo.i18n.calendar_field_index import CalendarFieldIndex as CalendarFieldIndex

    class CalendarFieldIndexEnum(IntEnum):
        """
        Enum of Const Class CalendarFieldIndex

        Field indices to be passed to various XCalendar methods.
        
        Field is writable only if marked both Get/Set.
        
        ZONE_OFFSET and DST_OFFSET cooperate such that both values are added, for example, ZoneOffset=1*60 and DstOffset=1*60 results in a time difference of GMT+2. The calculation in minutes is GMT = LocalTime - ZoneOffset - DstOffset
        
        With introduction of ZONE_OFFSET_SECOND_MILLIS and DST_OFFSET_SECOND_MILLIS the exact calculation in milliseconds is GMT = LocalTime
        
        **since**
        
            OOo 3.1
        """
        AM_PM = CalendarFieldIndex.AM_PM
        """
        Get AmPmValue.
        """
        DAY_OF_MONTH = CalendarFieldIndex.DAY_OF_MONTH
        """
        Get/Set day of month [1-31].
        """
        DAY_OF_WEEK = CalendarFieldIndex.DAY_OF_WEEK
        """
        Get day of week [0-6].
        """
        DAY_OF_YEAR = CalendarFieldIndex.DAY_OF_YEAR
        """
        Get day of year.
        """
        DST_OFFSET = CalendarFieldIndex.DST_OFFSET
        """
        Get daylight saving time offset in minutes, e.g.
        
        [0*60..1*60]
        
        The DST offset value depends on the actual date set at the calendar and is determined according to the timezone rules of the locale used with the calendar.
        
        Note that there is a bug in OpenOffice.org 1.0 / StarOffice 6.0 that prevents interpreting this value correctly.
        """
        HOUR = CalendarFieldIndex.HOUR
        """
        Get/Set hour [0-23].
        """
        MINUTE = CalendarFieldIndex.MINUTE
        """
        Get/Set minute [0-59].
        """
        SECOND = CalendarFieldIndex.SECOND
        """
        Get/Set second [0-59].
        """
        MILLISECOND = CalendarFieldIndex.MILLISECOND
        """
        Get/Set milliseconds [0-999].
        """
        WEEK_OF_MONTH = CalendarFieldIndex.WEEK_OF_MONTH
        """
        Get week of month.
        """
        WEEK_OF_YEAR = CalendarFieldIndex.WEEK_OF_YEAR
        """
        Get week of year.
        """
        YEAR = CalendarFieldIndex.YEAR
        """
        Get/Set year.
        """
        MONTH = CalendarFieldIndex.MONTH
        """
        Get/Set month [0-...].
        
        Note that the maximum value is not necessarily 11 for December but depends on the calendar used instead.
        """
        ERA = CalendarFieldIndex.ERA
        """
        Get/Set era, for example, 0:= Before Christ, 1:= After Christ.
        """
        ZONE_OFFSET = CalendarFieldIndex.ZONE_OFFSET
        """
        Get/Set time zone offset in minutes, e.g. [-14*60..14*60].
        """
        FIELD_COUNT = CalendarFieldIndex.FIELD_COUNT
        """
        Total number of fields for < OOo 3.1.
        """
        ZONE_OFFSET_SECOND_MILLIS = CalendarFieldIndex.ZONE_OFFSET_SECOND_MILLIS
        """
        Get/Set additional offset in milliseconds that adds to the value of ZONE_OFFSET.
        
        This may be necessary to correctly interpret historical timezone data that consists of fractions of minutes, e.g. seconds. 1 minute == 60000 milliseconds.
        
        **since**
        
            OOo 3.1
        """
        DST_OFFSET_SECOND_MILLIS = CalendarFieldIndex.DST_OFFSET_SECOND_MILLIS
        """
        Get additional offset in milliseconds that adds to the value of DST_OFFSET.
        
        This may be necessary to correctly interpret historical timezone data that consists of fractions of minutes, e.g. seconds. 1 minute == 60000 milliseconds.
        
        **since**
        
            OOo 3.1
        """
        FIELD_COUNT2 = CalendarFieldIndex.FIELD_COUNT2
        """
        Total number of fields as of OOo 3.1.
        
        **since**
        
            OOo 3.1
        """

__all__ = ['CalendarFieldIndex', 'CalendarFieldIndexEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.beans
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .property_state import PropertyState as PropertyState_c97b0c77

class XMultiPropertyStates(XInterface_8f010a43):
    """
    makes it possible to query information about the state of one or more properties.
    
    The state of a property contains information about the source of the value, e.g. the object itself, a default or a stylesheet. For more information see PropertyState.

    See Also:
        `API XMultiPropertyStates <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1beans_1_1XMultiPropertyStates.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.beans'
    __ooo_full_ns__: str = 'com.sun.star.beans.XMultiPropertyStates'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.beans.XMultiPropertyStates'

    @abstractmethod
    def getPropertyDefaults(self, aPropertyNames: typing.Tuple[str, ...]) -> typing.Tuple[object, ...]:
        """
        If no default exists, is not known, or is void, then the return type at the corresponding position in the sequence returned is void.

        Raises:
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...
    @abstractmethod
    def getPropertyStates(self, aPropertyName: typing.Tuple[str, ...]) -> typing.Tuple[PropertyState_c97b0c77, ...]:
        """
        The order of the states is correlating to the order of the given property names.

        Raises:
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
        """
        ...
    @abstractmethod
    def setAllPropertiesToDefault(self) -> None:
        """
        sets all properties to their default values.
        
        Each value depends on the implementation of this interface. If it is a bound property, you must change the value before the change events are fired. If it is a constrained property, you must fire the vetoable event before you change the property value.
        """
        ...
    @abstractmethod
    def setPropertiesToDefault(self, aPropertyNames: typing.Tuple[str, ...]) -> None:
        """
        sets the specified properties to their default values.
        
        Each value depends on the implementation of this interface. If it is a bound property, you must change the value before the change events are fired. If it is a constrained property, you must fire the vetoable event before you change the property value.

        Raises:
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
        """
        ...

__all__ = ['XMultiPropertyStates']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XPatternField(XInterface_8f010a43):
    """
    gives access to the value and formatting of a pattern field.

    See Also:
        `API XPatternField <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XPatternField.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XPatternField'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XPatternField'

    @abstractmethod
    def getMasks(self, EditMask: str, LiteralMask: str) -> None:
        """
        returns the currently set pattern mask.

        * ``EditMask`` is an out direction argument.
        * ``LiteralMask`` is an out direction argument.
        """
        ...
    @abstractmethod
    def getString(self) -> str:
        """
        returns the currently set string value of the pattern field.
        """
        ...
    @abstractmethod
    def isStrictFormat(self) -> bool:
        """
        returns whether the format is currently checked during user input.
        """
        ...
    @abstractmethod
    def setMasks(self, EditMask: str, LiteralMask: str) -> None:
        """
        sets the pattern mask.
        """
        ...
    @abstractmethod
    def setStrictFormat(self, bStrict: bool) -> None:
        """
        determines if the format is checked during user input.
        """
        ...
    @abstractmethod
    def setString(self, Str: str) -> None:
        """
        sets the string value of the pattern field.
        """
        ...

__all__ = ['XPatternField']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.document
from __future__ import annotations
import typing
from abc import abstractmethod, ABC
if typing.TYPE_CHECKING:
    from .x_document_event_listener import XDocumentEventListener as XDocumentEventListener_7db01146
    from ..frame.x_controller2 import XController2 as XController2_bbcf0bc1

class XDocumentEventBroadcaster(ABC):
    """
    allows to be notified of events happening in an OfficeDocument, and to cause notification of such events.
    
    This interface is the successor of the XEventBroadcaster interface, which should not be used anymore.
    
    **since**
    
        OOo 3.1

    See Also:
        `API XDocumentEventBroadcaster <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1document_1_1XDocumentEventBroadcaster.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.document'
    __ooo_full_ns__: str = 'com.sun.star.document.XDocumentEventBroadcaster'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.document.XDocumentEventBroadcaster'

    @abstractmethod
    def addDocumentEventListener(self, Listener: XDocumentEventListener_7db01146) -> None:
        """
        registers a listener which is notified about document events
        """
        ...
    @abstractmethod
    def notifyDocumentEvent(self, EventName: str, ViewController: XController2_bbcf0bc1, Supplement: object) -> None:
        """
        causes the broadcaster to notify all registered listeners of the given event
        
        The method will create a DocumentEvent instance with the given parameters, and fill in the Source member (denoting the broadcaster) as appropriate.
        
        Whether the actual notification happens synchronously or asynchronously is up to the implementor of this method. However, implementations are encouraged to specify this, for the list of supported event types, in their service contract.
        
        Implementations might also decide to limit the list of allowed events (means event names) at their own discretion. Again, in this case they're encouraged to document this in their service contract.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.NoSupportException: ``NoSupportException``
        """
        ...
    @abstractmethod
    def removeDocumentEventListener(self, Listener: XDocumentEventListener_7db01146) -> None:
        """
        revokes a listener which has previously been registered to be notified about document events.
        """
        ...

__all__ = ['XDocumentEventBroadcaster']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb.application
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class CopyTableOperation(metaclass=UnoConstMeta, type_name="com.sun.star.sdb.application.CopyTableOperation", name_space="com.sun.star.sdb.application"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.sdb.application.CopyTableOperation``"""
        pass

    class CopyTableOperationEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.sdb.application.CopyTableOperation", name_space="com.sun.star.sdb.application"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.sdb.application.CopyTableOperation`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.sdb.application import CopyTableOperation as CopyTableOperation
    else:
        # keep document generators happy
        from ....lo.sdb.application.copy_table_operation import CopyTableOperation as CopyTableOperation

    class CopyTableOperationEnum(IntEnum):
        """
        Enum of Const Class CopyTableOperation

        specifies the different basic operations a CopyTableWizard can do.
        
        **since**
        
            OOo 2.4
        """
        CopyDefinitionAndData = CopyTableOperation.CopyDefinitionAndData
        """
        specifies that the wizard should copy the source table to the target database, by creating a new table and copying all data.
        """
        CopyDefinitionOnly = CopyTableOperation.CopyDefinitionOnly
        """
        specifies that the wizard should copy the source table to the target database, by only creating a new table with the same structure as the source table.
        """
        CreateAsView = CopyTableOperation.CreateAsView
        """
        specifies the wizard should create the source table as view
        
        This option is not available if the target database does not support views.
        """
        AppendData = CopyTableOperation.AppendData
        """
        specifies the wizard should append the source table's data to an existing table in the target database.
        """

__all__ = ['CopyTableOperation', 'CopyTableOperationEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class LocaleItem(metaclass=UnoConstMeta, type_name="com.sun.star.i18n.LocaleItem", name_space="com.sun.star.i18n"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.i18n.LocaleItem``"""
        pass

    class LocaleItemEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.i18n.LocaleItem", name_space="com.sun.star.i18n"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.i18n.LocaleItem`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.i18n import LocaleItem as LocaleItem
    else:
        # keep document generators happy
        from ...lo.i18n.locale_item import LocaleItem as LocaleItem

    class LocaleItemEnum(IntEnum):
        """
        Enum of Const Class LocaleItem

        These are not used with the API but with an OOo internal wrapper class that caches the contents of an instance of LocaleDataItem and uses these values to access it's members for faster access.
        
        Whenever locale data items were added these values and the wrapper class would have to be adjusted to give the application an easier access.
        
        .. deprecated::
        
            Class is deprecated.
        """
        DATE_SEPARATOR = LocaleItem.DATE_SEPARATOR
        THOUSAND_SEPARATOR = LocaleItem.THOUSAND_SEPARATOR
        DECIMAL_SEPARATOR = LocaleItem.DECIMAL_SEPARATOR
        TIME_SEPARATOR = LocaleItem.TIME_SEPARATOR
        TIME_100SEC_SEPARATOR = LocaleItem.TIME_100SEC_SEPARATOR
        LIST_SEPARATOR = LocaleItem.LIST_SEPARATOR
        SINGLE_QUOTATION_START = LocaleItem.SINGLE_QUOTATION_START
        SINGLE_QUOTATION_END = LocaleItem.SINGLE_QUOTATION_END
        DOUBLE_QUOTATION_START = LocaleItem.DOUBLE_QUOTATION_START
        DOUBLE_QUOTATION_END = LocaleItem.DOUBLE_QUOTATION_END
        MEASUREMENT_SYSTEM = LocaleItem.MEASUREMENT_SYSTEM
        TIME_AM = LocaleItem.TIME_AM
        TIME_PM = LocaleItem.TIME_PM
        LONG_DATE_DAY_OF_WEEK_SEPARATOR = LocaleItem.LONG_DATE_DAY_OF_WEEK_SEPARATOR
        LONG_DATE_DAY_SEPARATOR = LocaleItem.LONG_DATE_DAY_SEPARATOR
        LONG_DATE_MONTH_SEPARATOR = LocaleItem.LONG_DATE_MONTH_SEPARATOR
        LONG_DATE_YEAR_SEPARATOR = LocaleItem.LONG_DATE_YEAR_SEPARATOR
        COUNT = LocaleItem.COUNT
        """
        count of items available
        """
        DECIMAL_SEPARATOR_ALTERNATIVE = LocaleItem.DECIMAL_SEPARATOR_ALTERNATIVE
        COUNT2 = LocaleItem.COUNT2
        """
        count of items available
        """

__all__ = ['LocaleItem', 'LocaleItemEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ui.dialogs
from __future__ import annotations
import typing
import uno
from abc import abstractmethod
from .x_wizard import XWizard as XWizard_bae60bc0
if typing.TYPE_CHECKING:
    from .x_wizard_controller import XWizardController as XWizardController_469d0fe4

class Wizard(XWizard_bae60bc0):
    """
    Service Class

    provides a framework for implementing a wizard dialog.
    
    **since**
    
        OOo 3.3

    See Also:
        `API Wizard <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1Wizard.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ui.dialogs'
    __ooo_full_ns__: str = 'com.sun.star.ui.dialogs.Wizard'
    __ooo_type_name__: str = 'service'

    @abstractmethod
    def createMultiplePathsWizard(self, PageIds: typing.Tuple[uno.ByteSequence, ...], Controller: XWizardController_469d0fe4) -> None:
        """
        creates a wizard with a multiple possible execution paths

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def createSinglePathWizard(self, PageIds: uno.ByteSequence, Controller: XWizardController_469d0fe4) -> None:
        """
        creates a wizard with a single execution path

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['Wizard']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .filter_connection import FilterConnection as FilterConnection_f01f0d97


class TableFilterField2(object):
    """
    Struct Class

    describes a single condition in a filter descriptor.
    
    This struct has the FilterOperator2 constants group as member, whereas the TableFilterField struct uses the FilterOperator enum.
    
    **since**
    
        OOo 3.2

    See Also:
        `API TableFilterField2 <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1sheet_1_1TableFilterField2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.TableFilterField2'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.sheet.TableFilterField2'
    """Literal Constant ``com.sun.star.sheet.TableFilterField2``"""

    def __init__(self, Connection: typing.Optional[FilterConnection_f01f0d97] = FilterConnection_f01f0d97.AND, Field: typing.Optional[int] = 0, Operator: typing.Optional[int] = 0, IsNumeric: typing.Optional[bool] = False, NumericValue: typing.Optional[float] = 0.0, StringValue: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            Connection (FilterConnection, optional): Connection value.
            Field (int, optional): Field value.
            Operator (int, optional): Operator value.
            IsNumeric (bool, optional): IsNumeric value.
            NumericValue (float, optional): NumericValue value.
            StringValue (str, optional): StringValue value.
        """
        super().__init__()

        if isinstance(Connection, TableFilterField2):
            oth: TableFilterField2 = Connection
            self.Connection = oth.Connection
            self.Field = oth.Field
            self.Operator = oth.Operator
            self.IsNumeric = oth.IsNumeric
            self.NumericValue = oth.NumericValue
            self.StringValue = oth.StringValue
            return

        kargs = {
            "Connection": Connection,
            "Field": Field,
            "Operator": Operator,
            "IsNumeric": IsNumeric,
            "NumericValue": NumericValue,
            "StringValue": StringValue,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._connection = kwargs["Connection"]
        self._field = kwargs["Field"]
        self._operator = kwargs["Operator"]
        self._is_numeric = kwargs["IsNumeric"]
        self._numeric_value = kwargs["NumericValue"]
        self._string_value = kwargs["StringValue"]


    @property
    def Connection(self) -> FilterConnection_f01f0d97:
        """
        specifies how the condition is connected to the previous condition.
        """
        return self._connection

    @Connection.setter
    def Connection(self, value: FilterConnection_f01f0d97) -> None:
        self._connection = value

    @property
    def Field(self) -> int:
        """
        specifies which field (column) is used for the condition.
        """
        return self._field

    @Field.setter
    def Field(self, value: int) -> None:
        self._field = value

    @property
    def Operator(self) -> int:
        """
        specifies the type of the condition as defined in FilterOperator2.
        """
        return self._operator

    @Operator.setter
    def Operator(self, value: int) -> None:
        self._operator = value

    @property
    def IsNumeric(self) -> bool:
        """
        selects whether the TableFilterField2.NumericValue or the TableFilterField2.StringValue is used.
        """
        return self._is_numeric

    @IsNumeric.setter
    def IsNumeric(self, value: bool) -> None:
        self._is_numeric = value

    @property
    def NumericValue(self) -> float:
        """
        specifies a numeric value for the condition.
        """
        return self._numeric_value

    @NumericValue.setter
    def NumericValue(self, value: float) -> None:
        self._numeric_value = value

    @property
    def StringValue(self) -> str:
        """
        specifies a string value for the condition.
        """
        return self._string_value

    @StringValue.setter
    def StringValue(self, value: str) -> None:
        self._string_value = value


__all__ = ['TableFilterField2']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing
from __future__ import annotations
import typing
from abc import abstractmethod, ABC
if typing.TYPE_CHECKING:
    from ..awt.size import Size as Size_576707ef
    from ..awt.x_bitmap import XBitmap as XBitmap_70cd0909
    from .x_draw_page import XDrawPage as XDrawPage_b07a0b57
    from ..rendering.x_bitmap import XBitmap as XBitmap_b1b70b7b
    from ..rendering.x_canvas import XCanvas as XCanvas_b19b0b7a

class XSlideRenderer(ABC):
    """
    Create preview bitmaps for single slides.

    See Also:
        `API XSlideRenderer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1drawing_1_1XSlideRenderer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.XSlideRenderer'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.drawing.XSlideRenderer'

    @abstractmethod
    def calculatePreviewSize(self, nSlideAspectRatio: float, aMaximumPreviewPixelSize: Size_576707ef) -> Size_576707ef:
        """
        Return a size that has the given aspect ratio and shares either the width or the height with the given maximum size.
        """
        ...
    @abstractmethod
    def createPreview(self, xSlide: XDrawPage_b07a0b57, aMaximumPreviewPixelSize: Size_576707ef, nSuperSampleFactor: int) -> XBitmap_70cd0909:
        """
        Create a preview for the given slide that has the same aspect ratio as the page and is as large as possible but not larger than the specified size.
        
        The reason for not using the given size directly as preview size and thus possibly changing the aspect ratio is that a) a different aspect ratio is not used often, and b) leaving the adaptation of the actual preview size (according to the aspect ratio of the slide) to the slide renderer is more convenient to the caller than having to this himself.
        """
        ...
    @abstractmethod
    def createPreviewForCanvas(self, xSlide: XDrawPage_b07a0b57, aMaximumPreviewPixelSize: Size_576707ef, nSuperSampleFactor: int, xCanvas: XCanvas_b19b0b7a) -> XBitmap_b1b70b7b:
        """
        Exactly the same functionality as createPreview(), only a different return type: com.sun.star.rendering.XBitmap instead of com.sun.star.awt.XBitmap.
        """
        ...

__all__ = ['XSlideRenderer']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml.crypto
from __future__ import annotations
import typing
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_security_environment import XSecurityEnvironment as XSecurityEnvironment_7ead116d

class XXMLSecurityContext(XInterface_8f010a43):
    """
    Interface of XML security context.
    
    This interface specifies a certain signature context. By signature context, the signer or verifier retrieves key specification.

    See Also:
        `API XXMLSecurityContext <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1XXMLSecurityContext.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.crypto'
    __ooo_full_ns__: str = 'com.sun.star.xml.crypto.XXMLSecurityContext'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.xml.crypto.XXMLSecurityContext'

    @abstractmethod
    def addSecurityEnvironment(self, aSecurityEnvironment: XSecurityEnvironment_7ead116d) -> int:
        """
        Add personal security environment , and return the index of the added environment.

        Raises:
            com.sun.star.security.SecurityInfrastructureException: ``SecurityInfrastructureException``
        """
        ...
    @abstractmethod
    def getDefaultSecurityEnvironmentIndex(self) -> int:
        """
        Get the ID of the internal security environment.
        """
        ...
    @abstractmethod
    def getSecurityEnvironment(self) -> XSecurityEnvironment_7ead116d:
        """
        An handy method to get the first personal security environment.
        
        In XMLSec/NSS, the first personal security environment should be the \"internal slot\"
        """
        ...
    @abstractmethod
    def getSecurityEnvironmentByIndex(self, index: int) -> XSecurityEnvironment_7ead116d:
        """
        Get personal security environment.
        """
        ...
    @abstractmethod
    def getSecurityEnvironmentNumber(self) -> int:
        """
        Get the number of security environments.
        """
        ...
    @abstractmethod
    def setDefaultSecurityEnvironmentIndex(self, index: int) -> None:
        """
        set the ID of the internal security environment
        """
        ...

__all__ = ['XXMLSecurityContext']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.util
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73

class XSortable(XInterface_8f010a43):
    """
    makes it possible to sort the contents of this object.
    
    The available properties describing the sort criteria are defined in the sort descriptor implemented by the object that implements this interface.
    
    There are older deprecated sort descriptors:
    
    And a new set of sort descriptors:
    
    Both types may be implemented by the same object. When calling the sort method however properties from different descriptors must not be mixed.

    See Also:
        `API XSortable <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1util_1_1XSortable.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.util'
    __ooo_full_ns__: str = 'com.sun.star.util.XSortable'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.util.XSortable'

    @abstractmethod
    def createSortDescriptor(self) -> typing.Tuple[PropertyValue_c9610c73, ...]:
        """
        The set of properties is specific to the type of object that implements this interface. Therefore they can usually be used only for objects of that same type.
        """
        ...
    @abstractmethod
    def sort(self, xDescriptor: typing.Tuple[PropertyValue_c9610c73, ...]) -> None:
        """
        sorts the contents of the object according to the specified properties.
        
        The specified properties are usually the same or a subset of those obtained by calling createSortDescriptor() on the same type of object.
        """
        ...

__all__ = ['XSortable']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from contextlib import suppress
import warnings
warnings.filterwarnings('module')
warnings.warn('The cssdyn namespace is deprecated. Use dyn instead.', DeprecationWarning, stacklevel=2)

with suppress(ImportError):
    from ....dyn.ui.dialogs.address_book_source_pilot import AddressBookSourcePilot as AddressBookSourcePilot
with suppress(ImportError):
    from ....dyn.ui.dialogs.common_file_picker_element_ids import CommonFilePickerElementIds as CommonFilePickerElementIds
with suppress(ImportError):
    from ....dyn.ui.dialogs.common_file_picker_element_ids import CommonFilePickerElementIdsEnum as CommonFilePickerElementIdsEnum
with suppress(ImportError):
    from ....dyn.ui.dialogs.control_actions import ControlActions as ControlActions
with suppress(ImportError):
    from ....dyn.ui.dialogs.control_actions import ControlActionsEnum as ControlActionsEnum
with suppress(ImportError):
    from ....dyn.ui.dialogs.dialog_closed_event import DialogClosedEvent as DialogClosedEvent
with suppress(ImportError):
    from ....dyn.ui.dialogs.executable_dialog_exception import ExecutableDialogException as ExecutableDialogException
with suppress(ImportError):
    from ....dyn.ui.dialogs.executable_dialog_results import ExecutableDialogResults as ExecutableDialogResults
with suppress(ImportError):
    from ....dyn.ui.dialogs.executable_dialog_results import ExecutableDialogResultsEnum as ExecutableDialogResultsEnum
with suppress(ImportError):
    from ....dyn.ui.dialogs.extended_file_picker_element_ids import ExtendedFilePickerElementIds as ExtendedFilePickerElementIds
with suppress(ImportError):
    from ....dyn.ui.dialogs.extended_file_picker_element_ids import ExtendedFilePickerElementIdsEnum as ExtendedFilePickerElementIdsEnum
with suppress(ImportError):
    from ....dyn.ui.dialogs.file_picker import FilePicker as FilePicker
with suppress(ImportError):
    from ....dyn.ui.dialogs.file_picker_event import FilePickerEvent as FilePickerEvent
with suppress(ImportError):
    from ....dyn.ui.dialogs.file_preview_image_formats import FilePreviewImageFormats as FilePreviewImageFormats
with suppress(ImportError):
    from ....dyn.ui.dialogs.file_preview_image_formats import FilePreviewImageFormatsEnum as FilePreviewImageFormatsEnum
with suppress(ImportError):
    from ....dyn.ui.dialogs.filter_options_dialog import FilterOptionsDialog as FilterOptionsDialog
with suppress(ImportError):
    from ....dyn.ui.dialogs.folder_picker import FolderPicker as FolderPicker
with suppress(ImportError):
    from ....dyn.ui.dialogs.listbox_control_actions import ListboxControlActions as ListboxControlActions
with suppress(ImportError):
    from ....dyn.ui.dialogs.listbox_control_actions import ListboxControlActionsEnum as ListboxControlActionsEnum
with suppress(ImportError):
    from ....dyn.ui.dialogs.template_description import TemplateDescription as TemplateDescription
with suppress(ImportError):
    from ....dyn.ui.dialogs.template_description import TemplateDescriptionEnum as TemplateDescriptionEnum
with suppress(ImportError):
    from ....dyn.ui.dialogs.wizard import Wizard as Wizard
with suppress(ImportError):
    from ....dyn.ui.dialogs.wizard_button import WizardButton as WizardButton
with suppress(ImportError):
    from ....dyn.ui.dialogs.wizard_button import WizardButtonEnum as WizardButtonEnum
with suppress(ImportError):
    from ....dyn.ui.dialogs.wizard_travel_type import WizardTravelType as WizardTravelType
with suppress(ImportError):
    from ....dyn.ui.dialogs.wizard_travel_type import WizardTravelTypeEnum as WizardTravelTypeEnum
with suppress(ImportError):
    from ....dyn.ui.dialogs.x_asynchronous_executable_dialog import XAsynchronousExecutableDialog as XAsynchronousExecutableDialog
with suppress(ImportError):
    from ....dyn.ui.dialogs.x_control_access import XControlAccess as XControlAccess
with suppress(ImportError):
    from ....dyn.ui.dialogs.x_control_information import XControlInformation as XControlInformation
with suppress(ImportError):
    from ....dyn.ui.dialogs.x_dialog_closed_listener import XDialogClosedListener as XDialogClosedListener
with suppress(ImportError):
    from ....dyn.ui.dialogs.x_executable_dialog import XExecutableDialog as XExecutableDialog
with suppress(ImportError):
    from ....dyn.ui.dialogs.x_file_picker import XFilePicker as XFilePicker
with suppress(ImportError):
    from ....dyn.ui.dialogs.x_file_picker2 import XFilePicker2 as XFilePicker2
with suppress(ImportError):
    from ....dyn.ui.dialogs.x_file_picker3 import XFilePicker3 as XFilePicker3
with suppress(ImportError):
    from ....dyn.ui.dialogs.x_file_picker_control_access import XFilePickerControlAccess as XFilePickerControlAccess
with suppress(ImportError):
    from ....dyn.ui.dialogs.x_file_picker_listener import XFilePickerListener as XFilePickerListener
with suppress(ImportError):
    from ....dyn.ui.dialogs.x_file_picker_notifier import XFilePickerNotifier as XFilePickerNotifier
with suppress(ImportError):
    from ....dyn.ui.dialogs.x_file_preview import XFilePreview as XFilePreview
with suppress(ImportError):
    from ....dyn.ui.dialogs.x_filter_group_manager import XFilterGroupManager as XFilterGroupManager
with suppress(ImportError):
    from ....dyn.ui.dialogs.x_filter_manager import XFilterManager as XFilterManager
with suppress(ImportError):
    from ....dyn.ui.dialogs.x_folder_picker import XFolderPicker as XFolderPicker
with suppress(ImportError):
    from ....dyn.ui.dialogs.x_folder_picker2 import XFolderPicker2 as XFolderPicker2
with suppress(ImportError):
    from ....dyn.ui.dialogs.xslt_filter_dialog import XSLTFilterDialog as XSLTFilterDialog
with suppress(ImportError):
    from ....dyn.ui.dialogs.x_wizard import XWizard as XWizard
with suppress(ImportError):
    from ....dyn.ui.dialogs.x_wizard_controller import XWizardController as XWizardController
with suppress(ImportError):
    from ....dyn.ui.dialogs.x_wizard_page import XWizardPage as XWizardPage



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.xml.crypto
# Libre Office Version: 7.4
from __future__ import annotations
from enum import Enum


class SecurityOperationStatus(Enum):
    """
    Enum Class


    See Also:
        `API SecurityOperationStatus <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1xml_1_1crypto.html#ab5d887eb5da1173b766d96d0d863d1dc>`_
    """
    __ooo_ns__: str = "com.sun.star.xml.crypto"
    __ooo_full_ns__: str = "com.sun.star.xml.crypto.SecurityOperationStatus"
    __ooo_type_name__: str = "enum"

    @property
    def typeName(self) -> str:
        return "com.sun.star.xml.crypto.SecurityOperationStatus"

    ASSERTION = "ASSERTION"
    """
    """
    CERT_HAS_EXPIRED = "CERT_HAS_EXPIRED"
    """
    """
    CERT_ISSUER_FAILED = "CERT_ISSUER_FAILED"
    """
    """
    CERT_NOT_FOUND = "CERT_NOT_FOUND"
    """
    """
    CERT_NOT_YET_VALID = "CERT_NOT_YET_VALID"
    """
    """
    CERT_REVOKED = "CERT_REVOKED"
    """
    """
    CERT_VERIFY_FAILED = "CERT_VERIFY_FAILED"
    """
    """
    CRYPTO_FAILED = "CRYPTO_FAILED"
    """
    """
    DATA_NOT_MATCH = "DATA_NOT_MATCH"
    """
    """
    DISABLED = "DISABLED"
    """
    """
    DSIG_INVALID_REFERENCE = "DSIG_INVALID_REFERENCE"
    """
    """
    DSIG_NO_REFERENCES = "DSIG_NO_REFERENCES"
    """
    """
    ENGINE_FAILED = "ENGINE_FAILED"
    """
    The following constants are derived from XMLSec error definitions, as following:
    
    XMLSEC_ERRORS_R_XMLSEC_FAILED XMLSEC_ERRORS_R_MALLOC_FAILED XMLSEC_ERRORS_R_STRDUP_FAILED XMLSEC_ERRORS_R_CRYPTO_FAILED XMLSEC_ERRORS_R_XML_FAILED XMLSEC_ERRORS_R_XSLT_FAILED XMLSEC_ERRORS_R_IO_FAILED XMLSEC_ERRORS_R_DISABLED XMLSEC_ERRORS_R_NOT_IMPLEMENTED XMLSEC_ERRORS_R_INVALID_SIZE XMLSEC_ERRORS_R_INVALID_DATA XMLSEC_ERRORS_R_INVALID_RESULT XMLSEC_ERRORS_R_INVALID_TYPE XMLSEC_ERRORS_R_INVALID_OPERATION XMLSEC_ERRORS_R_INVALID_STATUS XMLSEC_ERRORS_R_INVALID_FORMAT XMLSEC_ERRORS_R_DATA_NOT_MATCH XMLSEC_ERRORS_R_INVALID_NODE XMLSEC_ERRORS_R_INVALID_NODE_CONTENT XMLSEC_ERRORS_R_INVALID_NODE_ATTRIBUTE XMLSEC_ERRORS_R_MISSING_NODE_ATTRIBUTE XMLSEC_ERRORS_R_NODE_ALREADY_PRESENT XMLSEC_ERRORS_R_UNEXPECTED_NODE XMLSEC_ERRORS_R_NODE_NOT_FOUND XMLSEC_ERRORS_R_INVALID_TRANSFORM XMLSEC_ERRORS_R_INVALID_TRANSFORM_KEY XMLSEC_ERRORS_R_INVALID_URI_TYPE XMLSEC_ERRORS_R_TRANSFORM_SAME_DOCUMENT_REQUIRED XMLSEC_ERRORS_R_TRANSFORM_DISABLED XMLSEC_ERRORS_R_INVALID_KEY_DATA XMLSEC_ERRORS_R_KEY_DATA_NOT_FOUND XMLSEC_ERRORS_R_KEY_DATA_ALREADY_EXIST XMLSEC_ERRORS_R_INVALID_KEY_DATA_SIZE XMLSEC_ERRORS_R_KEY_NOT_FOUND XMLSEC_ERRORS_R_KEYDATA_DISABLED XMLSEC_ERRORS_R_MAX_RETRIEVALS_LEVEL XMLSEC_ERRORS_R_MAX_RETRIEVAL_TYPE_MISMATCH XMLSEC_ERRORS_R_MAX_ENCKEY_LEVEL XMLSEC_ERRORS_R_CERT_VERIFY_FAILED XMLSEC_ERRORS_R_CERT_NOT_FOUND XMLSEC_ERRORS_R_CERT_REVOKED XMLSEC_ERRORS_R_CERT_ISSUER_FAILED XMLSEC_ERRORS_R_CERT_NOT_YET_VALID XMLSEC_ERRORS_R_CERT_HAS_EXPIRED XMLSEC_ERRORS_R_DSIG_NO_REFERENCES XMLSEC_ERRORS_R_DSIG_INVALID_REFERENCE XMLSEC_ERRORS_R_ASSERTION XMLSEC_ERRORS_MAX_NUMBER
    """
    INVALID_DATA = "INVALID_DATA"
    """
    """
    INVALID_FORMAT = "INVALID_FORMAT"
    """
    """
    INVALID_KEY_DATA = "INVALID_KEY_DATA"
    """
    """
    INVALID_KEY_DATA_SIZE = "INVALID_KEY_DATA_SIZE"
    """
    """
    INVALID_NODE = "INVALID_NODE"
    """
    """
    INVALID_NODE_ATTRIBUTE = "INVALID_NODE_ATTRIBUTE"
    """
    """
    INVALID_NODE_CONTENT = "INVALID_NODE_CONTENT"
    """
    """
    INVALID_OPERATION = "INVALID_OPERATION"
    """
    """
    INVALID_RESULT = "INVALID_RESULT"
    """
    """
    INVALID_SIZE = "INVALID_SIZE"
    """
    """
    INVALID_STATUS = "INVALID_STATUS"
    """
    """
    INVALID_TRANSFORM = "INVALID_TRANSFORM"
    """
    """
    INVALID_TRANSFORM_KEY = "INVALID_TRANSFORM_KEY"
    """
    """
    INVALID_TYPE = "INVALID_TYPE"
    """
    """
    INVALID_URI_TYPE = "INVALID_URI_TYPE"
    """
    """
    IO_FAILED = "IO_FAILED"
    """
    """
    KEYDATA_DISABLED = "KEYDATA_DISABLED"
    """
    """
    KEY_DATA_ALREADY_EXIST = "KEY_DATA_ALREADY_EXIST"
    """
    """
    KEY_DATA_NOT_FOUND = "KEY_DATA_NOT_FOUND"
    """
    """
    KEY_NOT_FOUND = "KEY_NOT_FOUND"
    """
    """
    MALLOC_FAILED = "MALLOC_FAILED"
    """
    """
    MAX_ENCKEY_LEVEL = "MAX_ENCKEY_LEVEL"
    """
    """
    MAX_RETRIEVALS_LEVEL = "MAX_RETRIEVALS_LEVEL"
    """
    """
    MAX_RETRIEVAL_TYPE_MISMATCH = "MAX_RETRIEVAL_TYPE_MISMATCH"
    """
    """
    MISSING_NODE_ATTRIBUTE = "MISSING_NODE_ATTRIBUTE"
    """
    """
    NODE_ALREADY_PRESENT = "NODE_ALREADY_PRESENT"
    """
    """
    NODE_NOT_FOUND = "NODE_NOT_FOUND"
    """
    """
    NOT_IMPLEMENTED = "NOT_IMPLEMENTED"
    """
    """
    OPERATION_SUCCEEDED = "OPERATION_SUCCEEDED"
    """
    """
    RUNTIMEERROR_FAILED = "RUNTIMEERROR_FAILED"
    """
    """
    STRDUP_FAILED = "STRDUP_FAILED"
    """
    """
    TRANSFORM_DISABLED = "TRANSFORM_DISABLED"
    """
    """
    TRANSFORM_SAME_DOCUMENT_REQUIRED = "TRANSFORM_SAME_DOCUMENT_REQUIRED"
    """
    """
    UNEXPECTED_NODE = "UNEXPECTED_NODE"
    """
    """
    UNKNOWN = "UNKNOWN"
    """
    """
    XML_FAILED = "XML_FAILED"
    """
    """
    XSLT_FAILED = "XSLT_FAILED"
    """
    """

__all__ = ["SecurityOperationStatus"]




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.accessibility
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_accessible import XAccessible as XAccessible_1cbc0eb6
    from ..awt.point import Point as Point_5fb2085e
    from ..awt.rectangle import Rectangle as Rectangle_84b109e9
    from ..awt.size import Size as Size_576707ef
    from ..util.color import Color as Color_68e908c5

class XAccessibleComponent(XInterface_8f010a43):
    """
    The XAccessibleComponent interface should be supported by any class that can be rendered on the screen.
    
    This interface provides the standard mechanism for an assistive technology to retrieve information concerning the graphical representation of an object. This interface combines methods from the Java interfaces javax.accessibility.AccessibleComponent and javax.accessibility.AccessibleExtendedComponent.
    
    Further information about the graphical appearance of an object can be expressed with the XAccessibleExtendedComponent interface.
    
    Coordinates used by the functions of this interface are specified in different coordinate systems. Their scale is the same and is equal to that of the screen coordinate system. In other words all coordinates are measured in pixel. They differ in their respective origin:
    
    Key bindings which are associated with an accessible component can be retrieved at the component's action. The reason for this is that key bindings are associated with actions and directly with a component. This distinction becomes important when there are more than one action. To get access to the key bindings you have to get the XAccessibleAction interface of a component, provided that it is supported, and use the XAccessibleAction.getAccessibleKeyBinding().
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XAccessibleComponent <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1accessibility_1_1XAccessibleComponent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.accessibility'
    __ooo_full_ns__: str = 'com.sun.star.accessibility.XAccessibleComponent'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.accessibility.XAccessibleComponent'

    @abstractmethod
    def containsPoint(self, Point: Point_5fb2085e) -> bool:
        """
        Tests whether the specified point lies within this object's bounds.
        
        The test point's coordinates are defined relative to the coordinate system of the object. That means that when the object is an opaque rectangle then both the points (0,0) and (with-1,height-1) would yield a TRUE value.
        """
        ...
    @abstractmethod
    def getAccessibleAtPoint(self, Point: Point_5fb2085e) -> XAccessible_1cbc0eb6:
        """
        Returns the Accessible child that is rendered under the given point.
        
        The test point's coordinates are defined relative to the coordinate system of the object. That means that when the object is an opaque rectangle then both the points (0,0) and (with-1,height-1) would yield a TRUE value.
        """
        ...
    @abstractmethod
    def getBackground(self) -> Color_68e908c5:
        """
        Returns the background color of this object.
        """
        ...
    @abstractmethod
    def getBounds(self) -> Rectangle_84b109e9:
        """
        Returns the bounding box of this object.
        
        The returned bounding box has the form of a rectangle. Its coordinates are relative to the object's parent coordinate system. Note that the two methods getLocation() and getSize() return the same information. With method getLocationOnScreen() you can get the bound box position in screen coordinates.
        """
        ...
    @abstractmethod
    def getForeground(self) -> Color_68e908c5:
        """
        Returns the foreground color of this object.
        """
        ...
    @abstractmethod
    def getLocation(self) -> Point_5fb2085e:
        """
        Returns the location of the upper left corner of the object's bounding box relative to the parent.
        
        The coordinates of the bounding box are given relative to the parent's coordinate system.
        """
        ...
    @abstractmethod
    def getLocationOnScreen(self) -> Point_5fb2085e:
        """
        Returns the location of the upper left corner of the object's bounding box in screen coordinates.
        
        This method returns the same point as does the method getLocation(). The difference is that the coordinates are absolute screen coordinates of the screen to which the object is rendered instead of being relative to the object's parent.
        """
        ...
    @abstractmethod
    def getSize(self) -> Size_576707ef:
        """
        Returns the size of this object's bounding box.
        """
        ...
    @abstractmethod
    def grabFocus(self) -> None:
        """
        Grabs the focus to this object.
        
        If this object can not accept the focus, i.e. isFocusTraversable() returns FALSE for this object then nothing happens. Otherwise the object will attempt to take the focus. Nothing happens if that fails, otherwise the object has the focus. This method is called requestFocus in the Java Accessibility API 1.4.
        """
        ...

__all__ = ['XAccessibleComponent']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.rendering


class ColorSpaceType(object):
    """
    Const Class

    Categories for color spaces.

    See Also:
        `API ColorSpaceType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1rendering_1_1ColorSpaceType.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.rendering'
    __ooo_full_ns__: str = 'com.sun.star.rendering.ColorSpaceType'
    __ooo_type_name__: str = 'const'

    DEVICE_COLOR = 0
    """
    Unspecified device color space - use conversion functions to convert to standard color spaces.
    """
    GREY = 1
    """
    Grey-value color space.
    
    Use this for monochrome images.
    """
    RGB = 2
    """
    RGB color space.
    """
    CMYK = 3
    """
    CMYK color space.
    
    See Wikipedia for a thorough explanation.
    """
    CMYKOG = 4
    """
    CMYKOG color space.
    
    See Wikipedia for a thorough explanation.
    """
    CIEXYZ = 5
    """
    Standard CieXYZ color space.
    
    See Wikipedia for a thorough explanation.
    """
    CIELAB = 6
    """
    Standard CieLab color space.
    
    See Wikipedia for a thorough explanation. Preferable over CIEXYZ if perceptual uniformity is an issue.
    """
    SRGB = 7
    """
    Standard sRGB color space.
    
    See Wikipedia for a thorough explanation.
    """
    HSV = 8
    """
    HSV color space.
    
    Hue saturation value. See Wikipedia for a thorough explanation.
    """
    HSL = 9
    """
    HSL color space.
    
    Hue saturation lightness. See Wikipedia for a thorough explanation
    """
    YCBCR = 10
    """
    YCbCr color space.
    
    See Wikipedia for a thorough explanation. This color space is common for digital video.
    """
    INDEXED = 11
    """
    Indexed color space.
    
    The color components of this color space are in fact indices into a color map.
    """

__all__ = ['ColorSpaceType']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from contextlib import suppress
import warnings
warnings.filterwarnings('module')
warnings.warn('The cssdyn namespace is deprecated. Use dyn instead.', DeprecationWarning, stacklevel=2)

with suppress(ImportError):
    from ...dyn.presentation.animation_effect import AnimationEffect as AnimationEffect
with suppress(ImportError):
    from ...dyn.presentation.animation_speed import AnimationSpeed as AnimationSpeed
with suppress(ImportError):
    from ...dyn.presentation.chart_shape import ChartShape as ChartShape
with suppress(ImportError):
    from ...dyn.presentation.click_action import ClickAction as ClickAction
with suppress(ImportError):
    from ...dyn.presentation.custom_presentation import CustomPresentation as CustomPresentation
with suppress(ImportError):
    from ...dyn.presentation.custom_presentation_access import CustomPresentationAccess as CustomPresentationAccess
with suppress(ImportError):
    from ...dyn.presentation.date_time_shape import DateTimeShape as DateTimeShape
with suppress(ImportError):
    from ...dyn.presentation.document_settings import DocumentSettings as DocumentSettings
with suppress(ImportError):
    from ...dyn.presentation.draw_page import DrawPage as DrawPage
with suppress(ImportError):
    from ...dyn.presentation.effect_commands import EffectCommands as EffectCommands
with suppress(ImportError):
    from ...dyn.presentation.effect_commands import EffectCommandsEnum as EffectCommandsEnum
with suppress(ImportError):
    from ...dyn.presentation.effect_node_type import EffectNodeType as EffectNodeType
with suppress(ImportError):
    from ...dyn.presentation.effect_node_type import EffectNodeTypeEnum as EffectNodeTypeEnum
with suppress(ImportError):
    from ...dyn.presentation.effect_preset_class import EffectPresetClass as EffectPresetClass
with suppress(ImportError):
    from ...dyn.presentation.effect_preset_class import EffectPresetClassEnum as EffectPresetClassEnum
with suppress(ImportError):
    from ...dyn.presentation.fade_effect import FadeEffect as FadeEffect
with suppress(ImportError):
    from ...dyn.presentation.footer_shape import FooterShape as FooterShape
with suppress(ImportError):
    from ...dyn.presentation.graphic_object_shape import GraphicObjectShape as GraphicObjectShape
with suppress(ImportError):
    from ...dyn.presentation.handout_shape import HandoutShape as HandoutShape
with suppress(ImportError):
    from ...dyn.presentation.handout_view import HandoutView as HandoutView
with suppress(ImportError):
    from ...dyn.presentation.header_shape import HeaderShape as HeaderShape
with suppress(ImportError):
    from ...dyn.presentation.notes_shape import NotesShape as NotesShape
with suppress(ImportError):
    from ...dyn.presentation.notes_view import NotesView as NotesView
with suppress(ImportError):
    from ...dyn.presentation.ole2_shape import OLE2Shape as OLE2Shape
with suppress(ImportError):
    from ...dyn.presentation.outline_view import OutlineView as OutlineView
with suppress(ImportError):
    from ...dyn.presentation.outliner_shape import OutlinerShape as OutlinerShape
with suppress(ImportError):
    from ...dyn.presentation.page_shape import PageShape as PageShape
with suppress(ImportError):
    from ...dyn.presentation.paragraph_target import ParagraphTarget as ParagraphTarget
with suppress(ImportError):
    from ...dyn.presentation.presentation import Presentation as Presentation
with suppress(ImportError):
    from ...dyn.presentation.presentation2 import Presentation2 as Presentation2
with suppress(ImportError):
    from ...dyn.presentation.presentation_document import PresentationDocument as PresentationDocument
with suppress(ImportError):
    from ...dyn.presentation.presentation_range import PresentationRange as PresentationRange
with suppress(ImportError):
    from ...dyn.presentation.presentation_view import PresentationView as PresentationView
with suppress(ImportError):
    from ...dyn.presentation.preview_view import PreviewView as PreviewView
with suppress(ImportError):
    from ...dyn.presentation.shape import Shape as Shape
with suppress(ImportError):
    from ...dyn.presentation.shape_animation_sub_type import ShapeAnimationSubType as ShapeAnimationSubType
with suppress(ImportError):
    from ...dyn.presentation.shape_animation_sub_type import ShapeAnimationSubTypeEnum as ShapeAnimationSubTypeEnum
with suppress(ImportError):
    from ...dyn.presentation.slide_number_shape import SlideNumberShape as SlideNumberShape
with suppress(ImportError):
    from ...dyn.presentation.slide_show import SlideShow as SlideShow
with suppress(ImportError):
    from ...dyn.presentation.slides_view import SlidesView as SlidesView
with suppress(ImportError):
    from ...dyn.presentation.subtitle_shape import SubtitleShape as SubtitleShape
with suppress(ImportError):
    from ...dyn.presentation.text_animation_type import TextAnimationType as TextAnimationType
with suppress(ImportError):
    from ...dyn.presentation.text_animation_type import TextAnimationTypeEnum as TextAnimationTypeEnum
with suppress(ImportError):
    from ...dyn.presentation.title_text_shape import TitleTextShape as TitleTextShape
with suppress(ImportError):
    from ...dyn.presentation.transition_factory import TransitionFactory as TransitionFactory
with suppress(ImportError):
    from ...dyn.presentation.x_custom_presentation_supplier import XCustomPresentationSupplier as XCustomPresentationSupplier
with suppress(ImportError):
    from ...dyn.presentation.x_handout_master_supplier import XHandoutMasterSupplier as XHandoutMasterSupplier
with suppress(ImportError):
    from ...dyn.presentation.x_presentation import XPresentation as XPresentation
with suppress(ImportError):
    from ...dyn.presentation.x_presentation2 import XPresentation2 as XPresentation2
with suppress(ImportError):
    from ...dyn.presentation.x_presentation_page import XPresentationPage as XPresentationPage
with suppress(ImportError):
    from ...dyn.presentation.x_presentation_supplier import XPresentationSupplier as XPresentationSupplier
with suppress(ImportError):
    from ...dyn.presentation.x_shape_event_listener import XShapeEventListener as XShapeEventListener
with suppress(ImportError):
    from ...dyn.presentation.x_slide_show import XSlideShow as XSlideShow
with suppress(ImportError):
    from ...dyn.presentation.x_slide_show_controller import XSlideShowController as XSlideShowController
with suppress(ImportError):
    from ...dyn.presentation.x_slide_show_listener import XSlideShowListener as XSlideShowListener
with suppress(ImportError):
    from ...dyn.presentation.x_slide_show_view import XSlideShowView as XSlideShowView
with suppress(ImportError):
    from ...dyn.presentation.x_transition import XTransition as XTransition
with suppress(ImportError):
    from ...dyn.presentation.x_transition_factory import XTransitionFactory as XTransitionFactory



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.awt
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .rectangle import Rectangle as Rectangle_84b109e9


class DockingData(object):
    """
    Struct Class

    data returned by docking handler

    See Also:
        `API DockingData <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1awt_1_1DockingData.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.DockingData'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.awt.DockingData'
    """Literal Constant ``com.sun.star.awt.DockingData``"""

    def __init__(self, TrackingRectangle: typing.Optional[Rectangle_84b109e9] = UNO_NONE, bFloating: typing.Optional[bool] = False) -> None:
        """
        Constructor

        Arguments:
            TrackingRectangle (Rectangle, optional): TrackingRectangle value.
            bFloating (bool, optional): bFloating value.
        """
        super().__init__()

        if isinstance(TrackingRectangle, DockingData):
            oth: DockingData = TrackingRectangle
            self.TrackingRectangle = oth.TrackingRectangle
            self.bFloating = oth.bFloating
            return

        kargs = {
            "TrackingRectangle": TrackingRectangle,
            "bFloating": bFloating,
        }
        if kargs["TrackingRectangle"] is UNO_NONE:
            kargs["TrackingRectangle"] = None
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._tracking_rectangle = kwargs["TrackingRectangle"]
        self._b_floating = kwargs["bFloating"]


    @property
    def TrackingRectangle(self) -> Rectangle_84b109e9:
        """
        specifies the position and size where the window would be placed if the user releases the mouse
        """
        return self._tracking_rectangle

    @TrackingRectangle.setter
    def TrackingRectangle(self, value: Rectangle_84b109e9) -> None:
        self._tracking_rectangle = value

    @property
    def bFloating(self) -> bool:
        """
        specifies that the window should be floating (TRUE) or docked (FALSE)
        """
        return self._b_floating

    @bFloating.setter
    def bFloating(self, value: bool) -> None:
        self._b_floating = value


__all__ = ['DockingData']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form.binding
from __future__ import annotations
import typing
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43

class XValueBinding(XInterface_8f010a43):
    """
    specifies a binding to a value which can be read and written.

    See Also:
        `API XValueBinding <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1form_1_1binding_1_1XValueBinding.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form.binding'
    __ooo_full_ns__: str = 'com.sun.star.form.binding.XValueBinding'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.form.binding.XValueBinding'

    @abstractmethod
    def getSupportedValueTypes(self) -> typing.Tuple[object, ...]:
        """
        determines the types which are supported by this binding for value exchange
        """
        ...
    @abstractmethod
    def getValue(self, aType: object) -> object:
        """
        retrieves the current value

        Raises:
            IncompatibleTypesException: ``IncompatibleTypesException``
        """
        ...
    @abstractmethod
    def setValue(self, aValue: object) -> None:
        """
        sets the current value

        Raises:
            IncompatibleTypesException: ``IncompatibleTypesException``
            InvalidBindingStateException: ``InvalidBindingStateException``
            com.sun.star.lang.NoSupportException: ``NoSupportException``
        """
        ...
    @abstractmethod
    def supportsType(self, aType: object) -> bool:
        """
        determines whether a given type is supported by this binding for value exchange
        
        Calling this method is equal to calling getSupportedValueTypes(), and looking up the given type in the resulting type sequence.
        """
        ...

__all__ = ['XValueBinding']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.linguistic2
from __future__ import annotations
import typing
from abc import abstractmethod
from ..container.x_named import XNamed as XNamed_a6520b08
if typing.TYPE_CHECKING:
    from ..lang.locale import Locale as Locale_70d308fa
    from .x_dictionary_entry import XDictionaryEntry as XDictionaryEntry_49ef0ff5
    from .x_dictionary_event_listener import XDictionaryEventListener as XDictionaryEventListener_d74c132b
    from com.sun.star.linguistic2.DictionaryType import DictionaryTypeProto  # type: ignore

class XDictionary(XNamed_a6520b08):
    """
    This interfaces enables the object to access personal dictionaries.
    
    Personal dictionaries are used to supply additional information for spell checking and hyphenation (see com.sun.star.linguistic2.XDictionaryEntry). Only active dictionaries with an appropriate language are used for that purpose. The entries of an active, positive dictionary are words that are required to be recognized as correct during the spell checking process. Additionally, they will be used for hyphenation. Entries of a negative dictionary are required to be recognized as negative words, for example, words that should not be used, during SPELLCHECK. An entry in a negative dictionary may supply a proposal for a word to be used instead of the one being used.

    See Also:
        `API XDictionary <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XDictionary.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.linguistic2'
    __ooo_full_ns__: str = 'com.sun.star.linguistic2.XDictionary'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.linguistic2.XDictionary'

    @abstractmethod
    def add(self, aWord: str, bIsNegative: bool, aRplcText: str) -> bool:
        """
        is used to make an entry in the dictionary.
        
        If an entry already exists, the dictionary remains unchanged and FALSE will be returned.
        
        In positive dictionaries only positive entries can be made, and in negative ones only negative entries.
        """
        ...
    @abstractmethod
    def addDictionaryEventListener(self, xListener: XDictionaryEventListener_d74c132b) -> bool:
        """
        adds an entry to the list of dictionary event listeners.
        
        On dictionary events, each entry in the listener list will be notified via a call to com.sun.star.linguistic2.XDictionaryEventListener.processDictionaryEvent().
        """
        ...
    @abstractmethod
    def addEntry(self, xDicEntry: XDictionaryEntry_49ef0ff5) -> bool:
        """
        is used to add an entry to the dictionary.
        
        If an entry already exists, the dictionary remains unchanged and FALSE will be returned.
        
        In positive dictionaries only positive entries can be made, and in negative ones only negative entries.
        """
        ...
    @abstractmethod
    def clear(self) -> None:
        """
        removes all entries from the dictionary.
        """
        ...
    @abstractmethod
    def getCount(self) -> int:
        """
        """
        ...
    @abstractmethod
    def getDictionaryType(self) -> DictionaryTypeProto:
        """
        returns the type of the dictionary.
        """
        ...
    @abstractmethod
    def getEntries(self) -> typing.Tuple[XDictionaryEntry_49ef0ff5, ...]:
        """
        This function should no longer be used since with the expansion of the maximum number of allowed entries the result may become unreasonable large!
        """
        ...
    @abstractmethod
    def getEntry(self, aWord: str) -> XDictionaryEntry_49ef0ff5:
        """
        searches for an entry that matches the given word.
        """
        ...
    @abstractmethod
    def getLocale(self) -> Locale_70d308fa:
        """
        """
        ...
    @abstractmethod
    def isActive(self) -> bool:
        """
        """
        ...
    @abstractmethod
    def isFull(self) -> bool:
        """
        """
        ...
    @abstractmethod
    def remove(self, aWord: str) -> bool:
        """
        removes an entry from the dictionary.
        """
        ...
    @abstractmethod
    def removeDictionaryEventListener(self, xListener: XDictionaryEventListener_d74c132b) -> bool:
        """
        removes an entry from the list of dictionary event listeners.
        """
        ...
    @abstractmethod
    def setActive(self, bActivate: bool) -> None:
        """
        specifies whether the dictionary should be used or not .
        """
        ...
    @abstractmethod
    def setLocale(self, aLocale: Locale_70d308fa) -> None:
        """
        is used to set the language of the dictionary.
        """
        ...

__all__ = ['XDictionary']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class CharType(metaclass=UnoConstMeta, type_name="com.sun.star.i18n.CharType", name_space="com.sun.star.i18n"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.i18n.CharType``"""
        pass

    class CharTypeEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.i18n.CharType", name_space="com.sun.star.i18n"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.i18n.CharType`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.i18n import CharType as CharType
    else:
        # keep document generators happy
        from ...lo.i18n.char_type import CharType as CharType

    class CharTypeEnum(IntEnum):
        """
        Enum of Const Class CharType

        Constants to specify the character type that starts a character block.
        
        Character type is Unicode type defined in UnicodeType
        
        Used with XBreakIterator.beginOfCharBlock(), XBreakIterator.endOfCharBlock(), XBreakIterator.nextCharBlock(), XBreakIterator.previousCharBlock()
        """
        ANY_CHAR = CharType.ANY_CHAR
        """
        all alpha characters allowed
        """
        UPPERCASE_LETTER = CharType.UPPERCASE_LETTER
        LOWERCASE_LETTER = CharType.LOWERCASE_LETTER
        TITLECASE_LETTER = CharType.TITLECASE_LETTER
        MODIFIER_LETTER = CharType.MODIFIER_LETTER
        OTHER_LETTER = CharType.OTHER_LETTER
        NON_SPACING_MARK = CharType.NON_SPACING_MARK
        ENCLOSING_MARK = CharType.ENCLOSING_MARK
        COMBINING_SPACING_MARK = CharType.COMBINING_SPACING_MARK
        DECIMAL_DIGIT_NUMBER = CharType.DECIMAL_DIGIT_NUMBER
        LETTER_NUMBER = CharType.LETTER_NUMBER
        OTHER_NUMBER = CharType.OTHER_NUMBER
        SPACE_SEPARATOR = CharType.SPACE_SEPARATOR
        LINE_SEPARATOR = CharType.LINE_SEPARATOR
        PARAGRAPH_SEPARATOR = CharType.PARAGRAPH_SEPARATOR
        CONTROL = CharType.CONTROL
        FORMAT = CharType.FORMAT
        PRIVATE_USE = CharType.PRIVATE_USE
        SURROGATE = CharType.SURROGATE
        DASH_PUNCTUATION = CharType.DASH_PUNCTUATION
        START_PUNCTUATION = CharType.START_PUNCTUATION
        END_PUNCTUATION = CharType.END_PUNCTUATION
        CONNECTOR_PUNCTUATION = CharType.CONNECTOR_PUNCTUATION
        OTHER_PUNCTUATION = CharType.OTHER_PUNCTUATION
        MATH_SYMBOL = CharType.MATH_SYMBOL
        CURRENCY_SYMBOL = CharType.CURRENCY_SYMBOL
        MODIFIER_SYMBOL = CharType.MODIFIER_SYMBOL
        OTHER_SYMBOL = CharType.OTHER_SYMBOL
        INITIAL_PUNCTUATION = CharType.INITIAL_PUNCTUATION
        FINAL_PUNCTUATION = CharType.FINAL_PUNCTUATION
        GENERAL_TYPES_COUNT = CharType.GENERAL_TYPES_COUNT

__all__ = ['CharType', 'CharTypeEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form.runtime
from __future__ import annotations
import uno
from abc import abstractmethod, ABC

class XFeatureInvalidation(ABC):
    """
    implements a callback for a XFormOperations instance, which is called when the state of one or more FormFeatures might have changed.
    
    **since**
    
        OOo 2.2

    See Also:
        `API XFeatureInvalidation <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1form_1_1runtime_1_1XFeatureInvalidation.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form.runtime'
    __ooo_full_ns__: str = 'com.sun.star.form.runtime.XFeatureInvalidation'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.form.runtime.XFeatureInvalidation'

    @abstractmethod
    def invalidateAllFeatures(self) -> None:
        """
        invalidates all features
        
        This method is used of it cannot be exactly and reliably determined which features might actually have changed their state. In this case, the callee should assume all features it is interested in must be required.
        """
        ...
    @abstractmethod
    def invalidateFeatures(self, Features: uno.ByteSequence) -> None:
        """
        invalidates the given FormFeatures
        
        Invalidation means that any user interface representation (such as toolbox buttons), or any dispatches associated with the features in question are potentially out-of-date, and need to be updated.
        """
        ...

__all__ = ['XFeatureInvalidation']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml
from __future__ import annotations
import typing
from abc import abstractproperty, ABC
if typing.TYPE_CHECKING:
    from ..container.x_name_container import XNameContainer as XNameContainer_cb90e47

class UserDefinedAttributesSupplier(ABC):
    """
    Service Class

    A component that supports this service preserves XML attributes, unknown by its parser, that belong to the XML element representing it (the component).
    
    **since**
    
        OOo 2.0.4

    See Also:
        `API UserDefinedAttributesSupplier <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1xml_1_1UserDefinedAttributesSupplier.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml'
    __ooo_full_ns__: str = 'com.sun.star.xml.UserDefinedAttributesSupplier'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def UserDefinedAttributes(self) -> XNameContainer_cb90e47:
        """
        This container holds the AttributeData elements that represent uninterpreted XML attributes.
        
        The idea behind this property is that a parser can stow away all attributes that it cannot handle by itself on reading an XML file. When the file is stored again, the unknown attributes can be written back without loss.
        
        The com.sun.star.container.XNameContainer supports the service AttributeContainer.
        """
        ...


__all__ = ['UserDefinedAttributesSupplier']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_calendar3 import XCalendar3 as XCalendar3_927a09ed
if typing.TYPE_CHECKING:
    from ..lang.locale import Locale as Locale_70d308fa

class XCalendar4(XCalendar3_927a09ed):
    """
    This interface provides access to locale specific calendar systems.
    
    It is derived from com.sun.star.i18n.XCalendar3 and provides additional methods to set and get the local time.
    
    **since**
    
        LibreOffice 5.0

    See Also:
        `API XCalendar4 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1i18n_1_1XCalendar4.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.XCalendar4'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.i18n.XCalendar4'

    @abstractmethod
    def getLocalDateTime(self) -> float:
        """
        Get the local date/time as an offset to the start of the calendar at 1-Jan-1970 00:00.
        
        The integer part represents the number of days passed since start date. The fractional part represents fractions of a day, thus 0.5 means 12 hours.
        
        The actual timezone and daylight saving time offsets effective at the given date and time are considered and added to the UTC time at the calendar.
        """
        ...
    @abstractmethod
    def loadCalendarTZ(self, uniqueID: str, rLocale: Locale_70d308fa, TimeZone: str) -> None:
        """
        Load a specific calendar for the given locale with a given time zone.
        
        **since**
        
            LibreOffice 6.3
        """
        ...
    @abstractmethod
    def loadDefaultCalendarTZ(self, rLocale: Locale_70d308fa, TimeZone: str) -> None:
        """
        Load the default calendar for the given locale with a given time zone.
        
        **since**
        
            LibreOffice 6.3
        """
        ...
    @abstractmethod
    def setLocalDateTime(self, TimeInDays: float) -> None:
        """
        Set the local date/time as an offset to the start of the calendar at 1-Jan-1970 00:00.
        
        The integer part represents the number of days passed since start date. The fractional part represents fractions of a day, thus 0.5 means 12 hours.
        
        The actual timezone and daylight saving time offsets effective at the given date and time are considered and subtracted before setting the UTC time at the calendar.
        """
        ...

__all__ = ['XCalendar4']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.script
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_invocation import XInvocation as XInvocation_be070c0f
if typing.TYPE_CHECKING:
    from .invocation_info import InvocationInfo as InvocationInfo_e5270d43

class XInvocation2(XInvocation_be070c0f):
    """
    Extension of XInvocation to provide additional information about the methods and properties that are accessible via XInvocation.

    See Also:
        `API XInvocation2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1script_1_1XInvocation2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.script'
    __ooo_full_ns__: str = 'com.sun.star.script.XInvocation2'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.script.XInvocation2'

    @abstractmethod
    def getInfo(self) -> typing.Tuple[InvocationInfo_e5270d43, ...]:
        """
        returns information items for all methods and properties accessible via XInvocation.
        """
        ...
    @abstractmethod
    def getInfoForName(self, aName: str, bExact: bool) -> InvocationInfo_e5270d43:
        """
        returns information item for the method or property defined by aName

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def getMemberNames(self) -> typing.Tuple[str, ...]:
        """
        returns the names of all methods and properties accessible via XInvocation.
        """
        ...

__all__ = ['XInvocation2']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.style.break_type import BreakType as BreakType
from ...lo.style.case_map import CaseMap as CaseMap
from ...lo.style.cell_style import CellStyle as CellStyle
from ...lo.style.character_properties import CharacterProperties as CharacterProperties
from ...lo.style.character_properties_asian import CharacterPropertiesAsian as CharacterPropertiesAsian
from ...lo.style.character_properties_complex import CharacterPropertiesComplex as CharacterPropertiesComplex
from ...lo.style.character_style import CharacterStyle as CharacterStyle
from ...lo.style.drop_cap_format import DropCapFormat as DropCapFormat
from ...lo.style.footnote_line_style import FootnoteLineStyle as FootnoteLineStyle
from ...lo.style.graphic_location import GraphicLocation as GraphicLocation
from ...lo.style.horizontal_alignment import HorizontalAlignment as HorizontalAlignment
from ...lo.style.line_number_position import LineNumberPosition as LineNumberPosition
from ...lo.style.line_spacing import LineSpacing as LineSpacing
from ...lo.style.line_spacing_mode import LineSpacingMode as LineSpacingMode
from ...lo.style.numbering_alignment import NumberingAlignment as NumberingAlignment
from ...lo.style.numbering_level import NumberingLevel as NumberingLevel
from ...lo.style.numbering_rule import NumberingRule as NumberingRule
from ...lo.style.numbering_type import NumberingType as NumberingType
from ...lo.style.page_properties import PageProperties as PageProperties
from ...lo.style.page_style import PageStyle as PageStyle
from ...lo.style.page_style_layout import PageStyleLayout as PageStyleLayout
from ...lo.style.paragraph_adjust import ParagraphAdjust as ParagraphAdjust
from ...lo.style.paragraph_properties import ParagraphProperties as ParagraphProperties
from ...lo.style.paragraph_properties_asian import ParagraphPropertiesAsian as ParagraphPropertiesAsian
from ...lo.style.paragraph_properties_complex import ParagraphPropertiesComplex as ParagraphPropertiesComplex
from ...lo.style.paragraph_style import ParagraphStyle as ParagraphStyle
from ...lo.style.paragraph_style_category import ParagraphStyleCategory as ParagraphStyleCategory
from ...lo.style.style import Style as Style
from ...lo.style.style_families import StyleFamilies as StyleFamilies
from ...lo.style.style_family import StyleFamily as StyleFamily
from ...lo.style.tab_align import TabAlign as TabAlign
from ...lo.style.tab_stop import TabStop as TabStop
from ...lo.style.vertical_alignment import VerticalAlignment as VerticalAlignment
from ...lo.style.x_auto_style import XAutoStyle as XAutoStyle
from ...lo.style.x_auto_style_family import XAutoStyleFamily as XAutoStyleFamily
from ...lo.style.x_auto_styles import XAutoStyles as XAutoStyles
from ...lo.style.x_auto_styles_supplier import XAutoStylesSupplier as XAutoStylesSupplier
from ...lo.style.x_defaults_supplier import XDefaultsSupplier as XDefaultsSupplier
from ...lo.style.x_style import XStyle as XStyle
from ...lo.style.x_style_families_supplier import XStyleFamiliesSupplier as XStyleFamiliesSupplier
from ...lo.style.x_style_loader import XStyleLoader as XStyleLoader
from ...lo.style.x_style_loader2 import XStyleLoader2 as XStyleLoader2
from ...lo.style.x_style_supplier import XStyleSupplier as XStyleSupplier



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.resource
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_string_resource_resolver import XStringResourceResolver as XStringResourceResolver_92cb11d9
if typing.TYPE_CHECKING:
    from ..lang.locale import Locale as Locale_70d308fa

class XStringResourceManager(XStringResourceResolver_92cb11d9):
    """
    Interface to manage a resource string table containing a set of strings for different locales.
    
    The interface is derived from com.sun.star.resource.XStringResourceResolver that allows to access the string table but not to modify it. This interface also allows to modify the string table.
    
    It's designed to be used in the context of creating a string table, e.g. from a string table editor or from a Dialog Editor designing localized dialogs.

    See Also:
        `API XStringResourceManager <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1resource_1_1XStringResourceManager.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.resource'
    __ooo_full_ns__: str = 'com.sun.star.resource.XStringResourceManager'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.resource.XStringResourceManager'

    @abstractmethod
    def getUniqueNumericId(self) -> int:
        """
        Provides a numeric id that is unique within all Resource IDs used in the string table.
        
        This method takes into account all Resource IDs starting with a decimal number and only evaluates the ID until the first non digit character is reached. This allows to extend unique IDs with individual identifiers without breaking the mechanism of this method.
        
        Examples: ID \"42\" -> numeric id 42 ID \"0foo\" -> numeric id 0 ID \"111.MyId.Something.Else\" -> numeric id 111 ID \"No Digits\" -> not considered for numeric id
        
        The id returned will be 0 for an empty string table and it will be reset to 0 if all locales are removed. In all other cases this method returns the maximum numeric id used so far at the beginning of a Resource ID incremented by 1. When calling this method more than once always the same number will be returned until this number is really used at the beginning of a new Resource ID passed to setString() or setStringForLocale().
        
        As the numeric id is guaranteed to be unique for the complete string table all locales are taken into account. So using this methods will force the implementation to load all locale data that may not have been loaded so far.

        Raises:
            com.sun.star.lang.NoSupportException: ``NoSupportException``
        """
        ...
    @abstractmethod
    def isReadOnly(self) -> bool:
        """
        Returns the resource's read only state.
        """
        ...
    @abstractmethod
    def newLocale(self, locale: Locale_70d308fa) -> None:
        """
        Creates a new locale.
        
        For each existing ResourceID an empty string will be created. The first locale created will automatically be the first default locale. Otherwise strings for all already created IDs will be copied from the default locale.

        Raises:
            com.sun.star.container.ElementExistException: ``ElementExistException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.NoSupportException: ``NoSupportException``
        """
        ...
    @abstractmethod
    def removeId(self, ResourceID: str) -> None:
        """
        Removes a Resource ID including the corresponding string for the current locale.

        Raises:
            com.sun.star.resource.MissingResourceException: ``MissingResourceException``
            com.sun.star.lang.NoSupportException: ``NoSupportException``
        """
        ...
    @abstractmethod
    def removeIdForLocale(self, ResourceID: str, locale: Locale_70d308fa) -> None:
        """
        Removes a Resource ID including the corresponding string for s specific locale.

        Raises:
            com.sun.star.resource.MissingResourceException: ``MissingResourceException``
            com.sun.star.lang.NoSupportException: ``NoSupportException``
        """
        ...
    @abstractmethod
    def removeLocale(self, locale: Locale_70d308fa) -> None:
        """
        Removes a locale completely including the corresponding strings for each locale.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.NoSupportException: ``NoSupportException``
        """
        ...
    @abstractmethod
    def setCurrentLocale(self, Locale: Locale_70d308fa, FindClosestMatch: bool) -> None:
        """
        Sets the locale to be used.
        
        If true: If the exact locale that should be set is not available the method tries to find the closest match. E.g. if en_US is re- quired but not available, en would be the next choice. Finally the default locale will be used TRUE.
        
        If false: If the exact locale that should be set is not available a com.sun.star.lang.IllegalArgumentException is thrown.
        
        If false: If the exact locale that should be set is not available a com.sun.star.lang.IllegalArgumentException is thrown.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def setDefaultLocale(self, Locale: Locale_70d308fa) -> None:
        """
        Sets the default locale to be used.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.NoSupportException: ``NoSupportException``
        """
        ...
    @abstractmethod
    def setString(self, ResourceID: str, Str: str) -> None:
        """
        Associates a String to a Resource ID for the current locale.
        
        If an entry for the Resource ID already exists, the string associated with it will be overwritten, otherwise a new entry will be created.

        Raises:
            com.sun.star.lang.NoSupportException: ``NoSupportException``
        """
        ...
    @abstractmethod
    def setStringForLocale(self, ResourceID: str, Str: str, locale: Locale_70d308fa) -> None:
        """
        Associates a String to a Resource ID for a specific locale.
        
        If an entry for the Resource ID already exists, the string associated with it will be overwritten, otherwise a new entry will be created.
        
        It's not recommended to use this method to get the best performance as the implementation may be optimized for the use of the current locale.

        Raises:
            com.sun.star.lang.NoSupportException: ``NoSupportException``
        """
        ...

__all__ = ['XStringResourceManager']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .selection import Selection as Selection_84d609fa
    from .x_text_listener import XTextListener as XTextListener_b04d0b97

class XTextComponent(XInterface_8f010a43):
    """
    gives access to the text of a component and makes it possible to register event listeners.

    See Also:
        `API XTextComponent <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XTextComponent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XTextComponent'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XTextComponent'

    @abstractmethod
    def addTextListener(self, l: XTextListener_b04d0b97) -> None:
        """
        registers a text event listener.
        """
        ...
    @abstractmethod
    def getMaxTextLen(self) -> int:
        """
        returns the currently set maximum text length.
        """
        ...
    @abstractmethod
    def getSelectedText(self) -> str:
        """
        returns the currently selected text.
        """
        ...
    @abstractmethod
    def getSelection(self) -> Selection_84d609fa:
        """
        returns the current user selection.
        """
        ...
    @abstractmethod
    def getText(self) -> str:
        """
        returns the text of the component.
        """
        ...
    @abstractmethod
    def insertText(self, Sel: Selection_84d609fa, Text: str) -> None:
        """
        inserts text at the specified position.
        """
        ...
    @abstractmethod
    def isEditable(self) -> bool:
        """
        returns if the text is editable by the user.
        """
        ...
    @abstractmethod
    def removeTextListener(self, l: XTextListener_b04d0b97) -> None:
        """
        unregisters a text event listener.
        """
        ...
    @abstractmethod
    def setEditable(self, bEditable: bool) -> None:
        """
        makes the text editable for the user or read-only.
        """
        ...
    @abstractmethod
    def setMaxTextLen(self, nLen: int) -> None:
        """
        sets the maximum text length.
        """
        ...
    @abstractmethod
    def setSelection(self, aSelection: Selection_84d609fa) -> None:
        """
        sets the user selection.
        """
        ...
    @abstractmethod
    def setText(self, aText: str) -> None:
        """
        sets the text of the component.
        """
        ...

__all__ = ['XTextComponent']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form.control
from __future__ import annotations
from ...awt.uno_control_image_control import UnoControlImageControl as UnoControlImageControl_29c00f2b
from ..x_approve_action_broadcaster import XApproveActionBroadcaster as XApproveActionBroadcaster_693d10b9

class ImageButton(UnoControlImageControl_29c00f2b, XApproveActionBroadcaster_693d10b9):
    """
    Service Class

    describes a control which can be used for displaying images on a control acting like a button.
    
    The model of the control has to support the com.sun.star.form.component.ImageButton service.
    
    The control is clickable, the action taken upon clicking depends on the settings of the model the control belongs to.

    See Also:
        `API ImageButton <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1control_1_1ImageButton.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form.control'
    __ooo_full_ns__: str = 'com.sun.star.form.control.ImageButton'
    __ooo_type_name__: str = 'service'


__all__ = ['ImageButton']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml.sax
from __future__ import annotations
import typing
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_attribute_list import XAttributeList as XAttributeList_eec70d7b
    from .x_locator import XLocator as XLocator_a3fb0aff

class XDocumentHandler(XInterface_8f010a43):
    """
    receives notification of general document events.
    
    This interface is an IDL version of the Java interface org.xml.sax.DocumentHandler with some smaller adaptations.

    See Also:
        `API XDocumentHandler <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1sax_1_1XDocumentHandler.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.sax'
    __ooo_full_ns__: str = 'com.sun.star.xml.sax.XDocumentHandler'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.xml.sax.XDocumentHandler'

    @abstractmethod
    def characters(self, aChars: str) -> None:
        """
        receives notification of character data.

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
        ...
    @abstractmethod
    def endDocument(self) -> None:
        """
        receives notification of the end of a document.

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
        ...
    @abstractmethod
    def endElement(self, aName: str) -> None:
        """
        receives notification of the end of an element.

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
        ...
    @abstractmethod
    def ignorableWhitespace(self, aWhitespaces: str) -> None:
        """
        receives notification of white space that can be ignored.

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
        ...
    @abstractmethod
    def processingInstruction(self, aTarget: str, aData: str) -> None:
        """
        receives notification of a processing instruction.

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
        ...
    @abstractmethod
    def setDocumentLocator(self, xLocator: XLocator_a3fb0aff) -> None:
        """
        receives an object for locating the origin of SAX document events.

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
        ...
    @abstractmethod
    def startDocument(self) -> None:
        """
        receives notification of the beginning of a document.

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
        ...
    @abstractmethod
    def startElement(self, aName: str, xAttribs: XAttributeList_eec70d7b) -> None:
        """
        receives notification of the beginning of an element .

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
        ...

__all__ = ['XDocumentHandler']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.frame.status
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class UpperLowerMarginScale(object):
    """
    Struct Class

    specifies an upper and lower margin.
    
    **since**
    
        OOo 2.0

    See Also:
        `API UpperLowerMarginScale <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1frame_1_1status_1_1UpperLowerMarginScale.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame.status'
    __ooo_full_ns__: str = 'com.sun.star.frame.status.UpperLowerMarginScale'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.frame.status.UpperLowerMarginScale'
    """Literal Constant ``com.sun.star.frame.status.UpperLowerMarginScale``"""

    def __init__(self, Upper: typing.Optional[int] = 0, Lower: typing.Optional[int] = 0, ScaleUpper: typing.Optional[int] = 0, ScaleLower: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Upper (int, optional): Upper value.
            Lower (int, optional): Lower value.
            ScaleUpper (int, optional): ScaleUpper value.
            ScaleLower (int, optional): ScaleLower value.
        """
        super().__init__()

        if isinstance(Upper, UpperLowerMarginScale):
            oth: UpperLowerMarginScale = Upper
            self.Upper = oth.Upper
            self.Lower = oth.Lower
            self.ScaleUpper = oth.ScaleUpper
            self.ScaleLower = oth.ScaleLower
            return

        kargs = {
            "Upper": Upper,
            "Lower": Lower,
            "ScaleUpper": ScaleUpper,
            "ScaleLower": ScaleLower,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._upper = kwargs["Upper"]
        self._lower = kwargs["Lower"]
        self._scale_upper = kwargs["ScaleUpper"]
        self._scale_lower = kwargs["ScaleLower"]


    @property
    def Upper(self) -> int:
        """
        specifies a upper margin in 1/100th mm.
        """
        return self._upper

    @Upper.setter
    def Upper(self, value: int) -> None:
        self._upper = value

    @property
    def Lower(self) -> int:
        """
        specifies a lower margin in 1/100th mm.
        """
        return self._lower

    @Lower.setter
    def Lower(self, value: int) -> None:
        self._lower = value

    @property
    def ScaleUpper(self) -> int:
        """
        specifies a scale value for the upper margin.
        """
        return self._scale_upper

    @ScaleUpper.setter
    def ScaleUpper(self, value: int) -> None:
        self._scale_upper = value

    @property
    def ScaleLower(self) -> int:
        """
        specifies a scale value for the lower margin.
        """
        return self._scale_lower

    @ScaleLower.setter
    def ScaleLower(self, value: int) -> None:
        self._scale_lower = value


__all__ = ['UpperLowerMarginScale']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.beans
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .property_value import PropertyValue as PropertyValue_c9610c73

class XPropertyAccess(XInterface_8f010a43):
    """
    makes it possible to access all property values and to set them at once.
    
    In most cases this interface will be in addition to XPropertySet. It is especially useful for remote communication because it lessens the number of calls for getting property values; that is especially important because these calls are necessarily synchronous.
    
    Another advantage of this method is that conflicts are avoided if property value restrictions depend on the value of other properties.

    See Also:
        `API XPropertyAccess <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1beans_1_1XPropertyAccess.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.beans'
    __ooo_full_ns__: str = 'com.sun.star.beans.XPropertyAccess'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.beans.XPropertyAccess'

    @abstractmethod
    def getPropertyValues(self) -> typing.Tuple[PropertyValue_c9610c73, ...]:
        """
        """
        ...
    @abstractmethod
    def setPropertyValues(self, aProps: typing.Tuple[PropertyValue_c9610c73, ...]) -> None:
        """
        sets the values of given properties.
        
        All properties which are not contained in the sequence aProps will be left unchanged.

        Raises:
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
            com.sun.star.beans.PropertyVetoException: ``PropertyVetoException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...

__all__ = ['XPropertyAccess']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_database_parameter_broadcaster import XDatabaseParameterBroadcaster as XDatabaseParameterBroadcaster_ac7f1234
if typing.TYPE_CHECKING:
    from .x_database_parameter_listener import XDatabaseParameterListener as XDatabaseParameterListener_77e01110

class XDatabaseParameterBroadcaster2(XDatabaseParameterBroadcaster_ac7f1234):
    """
    provides the possibility of receiving an event for configuration of parameters.
    
    Note that this interface provides exactly the same functionality as the XDatabaseParameterBroadcaster interface. It exists purely for compatibility with the com.sun.star.script.XEventAttacher.attachSingleEventListener(): It expects the methods for adding and removing listeners to follow a certain naming scheme, respective to the name of the listener which is being added/removed.

    See Also:
        `API XDatabaseParameterBroadcaster2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1form_1_1XDatabaseParameterBroadcaster2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form'
    __ooo_full_ns__: str = 'com.sun.star.form.XDatabaseParameterBroadcaster2'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.form.XDatabaseParameterBroadcaster2'

    @abstractmethod
    def addDatabaseParameterListener(self, aListener: XDatabaseParameterListener_77e01110) -> None:
        """
        registers an XDatabaseParameterListener
        
        This method behaves exactly as the XDatabaseParameterBroadcaster.addParameterListener() method inherited from the base interface.
        """
        ...
    @abstractmethod
    def removeDatabaseParameterListener(self, aListener: XDatabaseParameterListener_77e01110) -> None:
        """
        revokes an XDatabaseParameterListener
        
        This method behaves exactly as the XDatabaseParameterBroadcaster.removeParameterListener() method inherited from the base interface.
        """
        ...

__all__ = ['XDatabaseParameterBroadcaster2']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.rendering
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class TexturingMode(metaclass=UnoConstMeta, type_name="com.sun.star.rendering.TexturingMode", name_space="com.sun.star.rendering"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.rendering.TexturingMode``"""
        pass

    class TexturingModeEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.rendering.TexturingMode", name_space="com.sun.star.rendering"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.rendering.TexturingMode`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.rendering import TexturingMode as TexturingMode
    else:
        # keep document generators happy
        from ...lo.rendering.texturing_mode import TexturingMode as TexturingMode

    class TexturingModeEnum(IntEnum):
        """
        Enum of Const Class TexturingMode

        Enumeration of possible values to spread a texture across a primitive.
        
        **since**
        
            OOo 2.0
        """
        NONE = TexturingMode.NONE
        """
        Pixel outside the texture area are fully transparent.
        
        This completely switches off pixel generation outside the texture coordinate range [0,1]. This results in only one instance of the texture generated per textured primitive.
        """
        CLAMP = TexturingMode.CLAMP
        """
        Clamp texture coordinate.
        
        This value clamps the texture coordinates to the range [0,1]. This results in only one instance of the texture generated per textured primitive, with the remaining area filled with the color of the outermost texels
        """
        REPEAT = TexturingMode.REPEAT
        """
        Repeat the texture.
        
        This value repeats the texture over the textured primitive, for the given texture coordinate.
        """

__all__ = ['TexturingMode', 'TexturingModeEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.document
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..uno.exception import Exception as Exception_85530a09
from ..uno.x_interface import XInterface as XInterface_8f010a43

class NoSuchFilterRequest(Exception_85530a09):
    """
    Exception Class

    should be used for interaction to handle states of unknown filter during detection
    
    If during loading time the filter can't be detected and wasn't given at calling time, a possible com.sun.star.task.InteractionHandler will be used. (it's a part of used MediaDescriptor) Such \"NoSuchFilterRequest\" will be used then to start right interaction on that to get a decision which filter should be used for given URL. A possible continuation of type XInteractionFilterSelect will transport this decision back to generic filter detection and force using of it. Of course it's possible to abort the loading process by use another continuation com.sun.star.task.XInteractionAbort.

    See Also:
        `API NoSuchFilterRequest <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1document_1_1NoSuchFilterRequest.html>`_
    """

    __ooo_ns__: str = 'com.sun.star.document'
    __ooo_full_ns__: str = 'com.sun.star.document.NoSuchFilterRequest'
    __ooo_type_name__: str = 'exception'
    __pyunointerface__: str = 'com.sun.star.document.NoSuchFilterRequest'
    __pyunostruct__: str = 'com.sun.star.document.NoSuchFilterRequest'

    typeName: str = 'com.sun.star.document.NoSuchFilterRequest'
    """Literal Constant ``com.sun.star.document.NoSuchFilterRequest``"""

    def __init__(self, Message: typing.Optional[str] = '', Context: typing.Optional[XInterface_8f010a43] = None, URL: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
            URL (str, optional): URL value.
        """
        kargs = {
            "Message": Message,
            "Context": Context,
            "URL": URL,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._url = kwargs["URL"]
        inst_keys = ('URL',)
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)

    @property
    def URL(self) -> str:
        """
        transport URL which couldn't be detected
        """
        return self._url
    
    @URL.setter
    def URL(self, value: str) -> None:
        self._url = value


__all__ = ['NoSuchFilterRequest']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdbcx
from __future__ import annotations
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from .x_alter_table import XAlterTable as XAlterTable_af4d0b54
from .x_columns_supplier import XColumnsSupplier as XColumnsSupplier_f0600da9
from .x_data_descriptor_factory import XDataDescriptorFactory as XDataDescriptorFactory_46170fe5
from .x_indexes_supplier import XIndexesSupplier as XIndexesSupplier_efa30d98
from .x_keys_supplier import XKeysSupplier as XKeysSupplier_c8a70c64
from .x_rename import XRename as XRename_848c09cc

class Table(XPropertySet_bc180bfa, XAlterTable_af4d0b54, XColumnsSupplier_f0600da9, XDataDescriptorFactory_46170fe5, XIndexesSupplier_efa30d98, XKeysSupplier_c8a70c64, XRename_848c09cc):
    """
    Service Class

    used to specify a table in a database.
    
    A table is described by its name and one or more columns.
    
    In addition, it may contain indexes to improve the performance in the retrieval of the table's data and keys, and to define semantic rules for the table.
    
    Note:  All properties and columns of a table could by modified before it is appended to a database. In that case, the service is in fact a descriptor. On existing tables, a user might alter columns, add or delete columns, indexes, and keys depending on the capabilities of the database and on the user's privileges.

    See Also:
        `API Table <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdbcx_1_1Table.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbcx'
    __ooo_full_ns__: str = 'com.sun.star.sdbcx.Table'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def CatalogName(self) -> str:
        """
        is the name of the table catalog.
        """
        ...

    @abstractproperty
    def Description(self) -> str:
        """
        supplies a comment on the table.
        
        Could be empty, if not supported by the driver.
        """
        ...

    @abstractproperty
    def Name(self) -> str:
        """
        is the name of the table.
        """
        ...

    @abstractproperty
    def SchemaName(self) -> str:
        """
        is the name of the table schema.
        """
        ...

    @abstractproperty
    def Type(self) -> str:
        """
        indicates the type of the table like (TABLE, VIEW, SYSTEM TABLE).
        
        Could be empty, if not supported by the driver.
        """
        ...


__all__ = ['Table']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt.tree
from __future__ import annotations
import typing
from abc import abstractproperty
from ..uno_control_model import UnoControlModel as UnoControlModel_c8ce0c58
if typing.TYPE_CHECKING:
    from .x_tree_data_model import XTreeDataModel as XTreeDataModel_f9fc0d85
    from com.sun.star.view.SelectionType import SelectionTypeProto  # type: ignore

class TreeControlModel(UnoControlModel_c8ce0c58):
    """
    Service Class

    specifies the standard model of a TreeControl.

    See Also:
        `API TreeControlModel <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1awt_1_1tree_1_1TreeControlModel.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt.tree'
    __ooo_full_ns__: str = 'com.sun.star.awt.tree.TreeControlModel'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def DataModel(self) -> XTreeDataModel_f9fc0d85:
        """
        Specifies the XTreeDataModel that is providing the hierarchical data.
        
        You can implement your own instance of XTreeDataModel or use the MutableTreeDataModel.
        """
        ...

    @abstractproperty
    def Editable(self) -> bool:
        """
        Specifies whether the nodes of the tree are editable.
        
        The default value is FALSE
        """
        ...

    @abstractproperty
    def InvokesStopNodeEditing(self) -> bool:
        """
        Specifies what happens when editing is interrupted by selecting another node in the tree, a change in the tree's data, or by some other means.
        
        Setting this property to TRUE causes the changes to be automatically saved when editing is interrupted. FALSE means that editing is canceled and changes are lost
        
        The default value is FALSE
        """
        ...

    @abstractproperty
    def RootDisplayed(self) -> bool:
        """
        Specifies if the root node of the tree is displayed.
        
        If RootDisplayed is set to FALSE, the root node of a model is no longer a valid node for the XTreeControl and can't be used with any method of XTreeControl.
        
        The default value is TRUE
        """
        ...

    @abstractproperty
    def RowHeight(self) -> int:
        """
        Specifies the height of each row, in pixels.
        
        If the specified value is less than or equal to zero, the row height is the maximum height of all rows.
        
        The default value is 0
        """
        ...

    @abstractproperty
    def SelectionType(self) -> SelectionTypeProto:
        """
        Specifies the selection mode that is enabled for this tree.
        
        The default value is com.sun.star.view.SelectionType.NONE
        """
        ...

    @abstractproperty
    def ShowsHandles(self) -> bool:
        """
        Specifies whether the node handles should be displayed.
        
        The handles are doted lines that visualize the tree like hierarchy
        
        The default value is TRUE
        """
        ...

    @abstractproperty
    def ShowsRootHandles(self) -> bool:
        """
        Specifies whether the node handles should also be displayed at root level.
        
        The default value is TRUE
        """
        ...


__all__ = ['TreeControlModel']


# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.configuration.backend
from __future__ import annotations
import typing
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_layer import XLayer as XLayer_4cd50fcb
    from .x_update_handler import XUpdateHandler as XUpdateHandler_d8f512ef

class XBackend(XInterface_8f010a43):
    """
    Handles access to layered data stored in a repository.
    
    Data can be retrieved on behalf of one or more entities.
    
    There is an implied owner entity associated to the object when it is created. This entity should be used for normal data access. For administrative operations data of other entities can be accessed.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XBackend <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1XBackend.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.configuration.backend'
    __ooo_full_ns__: str = 'com.sun.star.configuration.backend.XBackend'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.configuration.backend.XBackend'

    @abstractmethod
    def getOwnUpdateHandler(self, aComponent: str) -> XUpdateHandler_d8f512ef:
        """
        creates an update handler for the owner entity layer for a component.

        Raises:
            BackendAccessException: ``BackendAccessException``
            com.sun.star.lang.NoSupportException: ``NoSupportException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def getUpdateHandler(self, aComponent: str, aEntity: str) -> XUpdateHandler_d8f512ef:
        """
        creates an update handler on an entity's layer for a component.

        Raises:
            BackendAccessException: ``BackendAccessException``
            com.sun.star.lang.NoSupportException: ``NoSupportException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def listLayers(self, aComponent: str, aEntity: str) -> typing.Tuple[XLayer_4cd50fcb, ...]:
        """
        retrieves the layers associated to an entity for a component.

        Raises:
            BackendAccessException: ``BackendAccessException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def listOwnLayers(self, aComponent: str) -> typing.Tuple[XLayer_4cd50fcb, ...]:
        """
        retrieves the layers associated to the owner entity for a component.

        Raises:
            BackendAccessException: ``BackendAccessException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['XBackend']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form
from __future__ import annotations
from abc import abstractproperty
from ..beans.x_property_bag import XPropertyBag as XPropertyBag_bbd00bd8
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..container.x_named import XNamed as XNamed_a6520b08
from .x_form_component import XFormComponent as XFormComponent_c7fc0c5b
from ..io.x_persist_object import XPersistObject as XPersistObject_af2f0b79
from ..lang.x_component import XComponent as XComponent_98dc0ab5

class FormComponent(XPropertyBag_bbd00bd8, XPropertySet_bc180bfa, XNamed_a6520b08, XFormComponent_c7fc0c5b, XPersistObject_af2f0b79, XComponent_98dc0ab5):
    """
    Service Class

    specifies a component which can be part of a form.
    
    **since**
    
        OOo 2.3

    See Also:
        `API FormComponent <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1FormComponent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form'
    __ooo_full_ns__: str = 'com.sun.star.form.FormComponent'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Name(self) -> str:
        """
        the name of the component.
        
        Note that the name accessed here is the same as when using the com.sun.star.container.XNamed interface.
        """
        ...


__all__ = ['FormComponent']

